Pressure

Struct Pressure 

pub struct Pressure<M>{ /* private fields */ }
Mirror segments surface pressure

Analyze segments surface wind pressure from pressure files either M1p_M1p_*.csv.bz2 or M2p_M2p_*.csv.bz2 for M1 or M2, respectively.

Implementations

Source

impl<M> Pressure<M>

pub fn load(csv_pressure: String) -> Result<Self, PressureError>

Loads the pressure data

pub fn decompress(path: PathBuf) -> Result<String, PressureError>

pub fn load_pressure(contents: String) -> Result<Self, PressureError>

Loads the pressure from a csv bz2-compressed file

pub fn load_geometry(contents: String) -> Result<Self, PressureError>

Loads the areas and coordinates vector from a csv file

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn x_iter(&self) -> impl Iterator<Item = f64> + '_

pub fn x_range(&self) -> (f64, f64)

Returns the range of the x cooordinate

pub fn y_iter(&self) -> impl Iterator<Item = f64> + '_

Iterator over the y coordinate

pub fn xy_iter(&self) -> impl Iterator<Item = (f64, f64)> + '_

Iterator over the (x,y) coordinates

pub fn segment_xy(&self, sid: usize) -> impl Iterator<Item = (f64, f64)> + '_

Iterator over the (x,y) coordinates of a given segment

pub fn segment_pa(&self, sid: usize) -> impl Iterator<Item = (f64, f64)> + '_

Iterator over the pressure and areas of a given segment

pub fn y_range(&self) -> (f64, f64)

Returns the range of the y cooordinate

pub fn z_iter(&self) -> impl Iterator<Item = f64> + '_

Iterator over the z coordinate

pub fn z_range(&self) -> (f64, f64)

Returns the range of the z cooordinate

pub fn to_local(&mut self, sid: usize) -> Result<&mut Self, PressureError>

Transforms the coordinates into the segment local coordinate system

pub fn from_local(&mut self, sid: usize) -> &mut Self

Transforms the coordinates into the OSS

pub fn local_radial_filter( &self, sid: usize, r_in: Option<f64>, r_out: Option<f64>, ) -> impl Iterator<Item = bool> + '_

Filter that is apply locally to segment sid selecting samplea within the radii r_in<0> and r_out<exo_radius>

pub fn total_force(&self) -> f64

Returns the sum of the z forces of all the segments

pub fn pa_iter(&self) -> impl Iterator<Item = (&f64, &f64)>

Iterator over the pressures and areas

pub fn paijk_iter(&self) -> impl Iterator<Item = (&f64, &[f64; 3])>

Iterator over the pressures and area vectors

pub fn p_aijk_xyz(&self) -> impl Iterator<Item = (&f64, &[f64; 3], &[f64; 3])>

Iterator over the pressures, area vectors and coordinates

pub fn segment_p_aijk_xyz( &self, sid: usize, ) -> impl Iterator<Item = (&f64, &[f64; 3], &[f64; 3])>

Iterator over the pressures, area vectors and coordinates for the given segment

pub fn segment_area(&self, sid: usize) -> f64

Return the area of a given segment

pub fn segments_area(&self) -> Vec<f64>

Return the area of each segment

pub fn mirror_area(&self) -> f64

Return the mirror area

pub fn forces(&mut self, sid: usize) -> Result<Vec<[f64; 3]>, PressureError>

Returns the vectors of forces of a given segment

pub fn average_pressure(&self, sid: usize) -> f64

Returns the average pressure over a given segment

pub fn asm_differential_pressure(&self, sid: usize) -> (f64, Vec<f64>)

Returns the average ASM different pressure over a given segment

pub fn pressure_var(&mut self, sid: usize) -> f64

Returns the pressure variance over a given segment

pub fn pressure_std(&mut self, sid: usize) -> f64

Returns the pressure standard deviation over a given segment

pub fn segments_average_pressure(&mut self) -> Vec<f64>

Returns the average pressure over each segment

pub fn segments_pressure_var(&mut self) -> Vec<f64>

Returns the pressure variance over each segment

pub fn segments_pressure_std(&mut self) -> Vec<f64>

Returns the pressure standard deviation over each segment

pub fn mirror_average_pressure(&mut self) -> f64

Returns the average mean pressure over all segment

pub fn mirror_average_pressure_var(&mut self) -> f64

Returns the average pressure variance over all segment

pub fn mirror_average_pressure_std(&mut self) -> f64

Returns the average pressure standart deviation over all segment

pub fn mirror_average_pressure_within(&self, radius: f64) -> f64

Returns the average mean pressure over all segment within the given radius

pub fn mirror_average_pressure_by( &self, select: impl Iterator<Item = bool>, ) -> f64

Returns the average mean pressure over all segment with data filtered with select

pub fn mirror_average_pressure_var_within(&self, radius: f64) -> f64

Returns the average pressure variance over all segment within the given radius

pub fn mirror_average_pressure_var_by( &self, p_mean: f64, select: impl Iterator<Item = bool>, ) -> f64

Returns the average pressure variance over all segment with data filtered with select

pub fn center_of_pressure( &mut self, sid: usize, ) -> Result<[f64; 3], PressureError>

Returns the center of pressure of a given segment

pub fn segment_force(&mut self, sid: usize) -> Result<[f64; 3], PressureError>

Returns the sum of the forces of a given segment

pub fn segment_pressure_integral( &mut self, sid: usize, ) -> Result<([f64; 3], ([f64; 3], [f64; 3])), PressureError>

Returns the center of pressure and the force and moment applied at this location for a given segment

pub fn segments_force(&mut self) -> Result<[f64; 3], PressureError>

Returns the sum of the forces of all the segments

pub fn sum_vectors<'a>( &'a mut self, vec: impl Iterator<Item = &'a [f64; 3]>, ) -> [f64; 3]

Returns the sum of the vectors in Iterator

pub fn pressure_map(&mut self, cfd_case_path: PathBuf)

Display the pressure map